@@ -7,7 +7,7 @@ import copy
 import json
 import sqlite3
 import multiprocessing
-from typing import Any
+from typing import Any, List
 from . import lib, cursor, search
 
 
@@ -595,28 +595,47 @@ class Collection(object):
         with self.db:
             self.db.execute("DROP TABLE %s " % self.name)
 
-    def add_columns(self, columns:list):
+    def add_columns(self, columns:List[str], enforce_index=False):
         """
-        To add columns 
-        Args:
-            colums: list
-                [
-                    (column, type),
-                    (column, type),
-                    (column, 'text', 'UNIQUE'|True)
-                ]
+        To add columns. With options to add indexes
 
+        Args:
+            columns: 
+                List[str] -> "COLUMN:TYPE@INDEX"
+                    [
+                        "column", # column only. Type is in
+                        "column:type", # column and type
+                        "column:type@index", # column, type and index
+                        "column:type@unique" # column type and unique index
+                        "column@unique" # column and unique index. Type is inferred
+                    ]
+            
+            enforce_index:
+                bool - To make all prop an index.
         Returns:
             None
         """
+        cols_stmt = []
+        for idx in columns:
+            if isinstance(idx, str):
+                _type = "TEXT"
+                indx = False
+                col = idx
+                if "@" in col:
+                    col, indx =  col.split("@")
+                    indx = "UNIQUE" if indx.upper() == "UNIQUE" else True
+                if ":" in col:
+                    col, _type = col.split(":")
+                if enforce_index and indx != "UNIQUE":
+                    indx = True
+                cols_stmt.append((col, _type or "TEXT", indx))
+
+
         with self.db:
-            for _ in columns:
+            for _ in cols_stmt:
                 try:
-                    colindex = None
-                    if len(_) == 3:
-                        col, coltype, colindex = _
-                    else:
-                        col, coltype = _
+ 
+                    col, coltype, colindex = _
 
                     # Add column if not exists
                     if col not in self.columns: 
@@ -638,45 +657,15 @@ class Collection(object):
         self._columns = []
         self._indexes = []
 
-    def add_indexes(self, indexes:list):
+    def add_indexes(self, columns:List[str]):
         """
-        Add indexes ensuring columns
+        To indexed columns
 
-        Args:
-            indexes: list of indexes. 
-
-            :format:
-            [
-                column:str # index the column
-                (column) # index the column
-                (column, "UNIQUE") # index column as unique
-                (column, True) # index column as unique
-                (column, TYPE=TEXT|INT...) index column with type 
-                (column, TYPE=TEXT|INT..., "UNIQUE") index column with type and unique
-            ]
-
-        Returns:
-            None
+        Args: 
+            columns:
+                List[str]. Documentation-> #add_columns
         """
-        new_indexes = []
-        for idx in indexes:
-            if isinstance(idx, str):
-                new_indexes.append((idx, 'TEXT', True))
-            elif isinstance(idx, (list, set, tuple)):
-                if len(idx) == 1: # colum
-                    new_indexes.append((idx[0], 'TEXT', True))
-                elif len(idx) == 2: # (column, columntype)
-                    _type = idx[1]
-                    # Unique index - (column, ':UNIQUE:') or (column, True)
-                    if _type == "UNIQUE" or _type is True: 
-                        new_indexes.append((idx[0], 'TEXT', "UNIQUE"))
-                    # (column, 'TEXT|INT|...')
-                    else:
-                        new_indexes.append((idx[0], _type, True))
-                elif len(idx) == 3: # (column, type, UNIQUE)
-                    new_indexes.append((idx[0], idx[1], idx[2]))
-        if new_indexes:
-            self.add_columns(new_indexes)
+        self.add_columns(columns=columns, enforce_index=True)
 
 
     def __len__(self):
